@@ -1,11 +1,8 @@
 use strict;
 use warnings;
 package Task::Kensho::WebDev;
-BEGIN {
-  $Task::Kensho::WebDev::AUTHORITY = 'cpan:PERIGRIN';
-}
-# git description: v0.35-38-g5bd0b68
-$Task::Kensho::WebDev::VERSION = '0.36';
+# git description: v0.36-35-g35b32f1
+$Task::Kensho::WebDev::VERSION = '0.37';
 # ABSTRACT: A Glimpse at an Enlightened Perl: Web Development
 
 __END__
@@ -20,7 +17,7 @@ Task::Kensho::WebDev - A Glimpse at an Enlightened Perl: Web Development
 
 =head1 VERSION
 
-version 0.36
+version 0.37
 
 =head1 SYNOPSIS
 
@@ -69,10 +66,10 @@ facilitates the ease and simplicity the distribution aims to achieve.
 
 =head1 RECOMMENDED MODULES
 
-=head2 L<Task::Kensho::WebDev>: Web Development
-
 =for stopwords configs RSS
 
+=head2 L<Task::Kensho::WebDev>: Web Development
+
 =head3 L<CGI::FormBuilder::Source::Perl>
 
 Build CGI::FormBuilder configs from Perl syntax files.
@@ -150,4 +147,24 @@ This software is copyright (c) 2008 by Chris Prather.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 CONTRIBUTORS
+
+=for stopwords Karen Etheridge Leo Lapworth Chris Nehren
+
+=over 4
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Leo Lapworth <leo@cuckoo.org>
+
+=item *
+
+Chris Nehren <apeiron@cpan.org>
+
+=back
+
 =cut
